import express from 'express';
import config, { fetchAssistantSettings } from './config/appConfig';
import fs from 'fs/promises';
import path from 'path';
import fetch from 'node-fetch';

const router = express.Router();

router.post('/', async (req, res) => {
  console.log('Webhook request received:', req.body);
  const authHeader = req.headers.authorization;
  if (!authHeader || !authHeader.startsWith('Bearer ')) {
    console.log('Webhook request received without proper authorization');
    return res.status(401).json({ error: 'Unauthorized' });
  }

  const token = authHeader.split(' ')[1];
  if (token !== config.voice360ApiKey) {
    console.log('Webhook request received with invalid API key');
    return res.status(401).json({ error: 'Invalid API key' });
  }

  try {
    // Fetch the latest assistant settings from the API
    const apiUrl = new URL('/admin/voice360/API/get_all_assistant_settings', config.perfexCrmUrl);
    const response = await fetch(apiUrl.toString(), {
      headers: {
        'Accept': 'application/json',
        'X-Requested-With': 'XMLHttpRequest',
        'Authorization': `Bearer ${config.voice360ApiKey}`
      }
    });

    if (!response.ok) {
      throw new Error(`API request failed with status ${response.status}`);
    }

    const latestSettings = await response.json();

    // Update the assistantSettings.json file
    const cachePath = path.join(__dirname, '..', 'cache_settings', 'assistantSettings.json');
    await fs.writeFile(cachePath, JSON.stringify(latestSettings, null, 2));

    console.log('assistantSettings.json updated successfully via webhook');
    res.json({ message: 'Assistant settings updated successfullyw' });
  } catch (error) {
    console.error('Error updating assistant settings via webhook', error);
    res.status(500).json({ error: 'Failed to update assistant settings' });
  }
});

// Test endpoint
router.get('/test', (req, res) => {
  console.log('Test webhook endpoint hit');
  res.json({ message: 'Webhook is working' });
});

export default router;
